CV_delta: Cross validation to select delta

Description Usage Arguments Value

View source: R/CV.R

Description

Cross validation for choosing the tuning parameter δ. For each value of deltaGrids, first split the data into two parts and calculate I, A_I and Cov(Z). Then calculate the fit A_I Cov(Z) A_I' to find the value which minimizes the loss criterion

||Σ - A_I Cov(Z) A_I'||_{F-off}/(|I|(|I|-1))

.

Usage

1
CV_delta(X, deltaGrids, diagonal, se_est, merge)

Arguments

X

A n by p data matrix.

deltaGrids

A vector of numerical constants.

diagonal

Logical. If TRUE, the covariance matrix of Z is diagonal; else FALSE.

se_est

The vector of the standard deviations of p features.

merge

Logical. If TRUE, take the union of all candidate pure variables; otherwise, take the intersection.

Value

A numeric constant. The selected optimal δ.


bingx1990/LOVE documentation built on Jan. 23, 2022, 1:30 a.m.