Description Usage Arguments Value
KfoldCV_delta uses nfolds cross-validation to
select delta.
1 2 3 4 5 6 7 8 9 | KfoldCV_delta(
X,
delta = NULL,
ndelta = 50,
q = 2,
exact = FALSE,
nfolds = 10,
max_pure = NULL
)
|
X |
A n by p data matrix. |
delta |
The grid of leading constant of δ. |
ndelta |
Integer. The length of the grid of |
q |
Either |
exact |
Logical. Only active for compute the |
nfolds |
The number of folds. Default is 10. |
max_pure |
A numeric value between (0, 1] specifying the maximal
proportion of pure variables. Default is NULL. When not specified,
|
A list of objects including:
foldid The indices of observations used for cv.
delta_min The value of delta that has the minimum cv
error.
delta_1se The smallest and largest value of delta such
that the cv errors are wihtin one standard error of the minimum cv error.
delta The used delta sequence.
cv_mean The averaged cv errors.
cv_sd The standard errors of cv errors.
est_pure A list including:
K The cardinality of parallel rows.
I The index of parallel rows.
I_part The partition of parallel rows.
score The score matrix.
moments The crossproduct matrix R'R.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.