Description Usage Arguments Value See Also
Screen_X finds features that are close to pure noise via
k-fold cross-validation.
1 |
X |
A n by p data matrix. |
thresh_grid |
A numeric vector of thresholds. Default is |
nfolds |
The number of folds. Default is 10. |
nthresh |
Integer. The length of |
max_prop |
A numeric value between [0, 1] specifying the maximal proportional of pure noise features. Default is 0.5 meaning that at most 50% of features are pure noise. |
When only one value is provided in thresh_grid, Screen_X
returns a vector of indices that are detected as pure noise. When either
thresh_grid is NULL or multiple values are provided in
thresh_grid, Screen_X returns a list including
foldid The indices of observations used for cv.
thresh_min The value of thresh_grid that has the
minimum cv error.
thresh_1se The largest value of thresh_grid such that
the errors are wihtin one standard error of the minimum cv error.
thresh_grid The used thresh_grid sequence.
cv_mean The averaged cv errors.
cv_sd The standard errors of cv errors.
noise_ind a vector of indices that are detected as pure noise
by using thresh_min.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.