Description Usage Arguments Value
Cross validation for choosing the tuning parameter δ.
For each value of deltaGrids, first split the data into two parts
and calculate I, A_I and Cov(Z). Then calculate the fit
A_I Cov(Z) A_I' to find the value which minimizes the loss criterion
||Σ - A_I Cov(Z) A_I'||_{F-off}/(|I|(|I|-1))
.
1 |
X |
A n by p data matrix. |
deltaGrids |
A vector of numerical constants. |
diagonal |
Logical. If TRUE, the covariance matrix of Z is diagonal; else FALSE. |
se_est |
The vector of the standard deviations of p features. |
merge |
Logical. If TRUE, take the union of all candidate pure variables; otherwise, take the intersection. |
A numeric constant. The selected optimal δ.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.